@@ -1,3 +1,5 @@
+use anyhow::Result;
+
 use super::hrd_parameters::HrdParameters;
 use super::profile_tier_level::ProfileTierLevel;
 use super::BitVecReader;
@@ -24,7 +26,7 @@ pub struct VPSNAL {
 }
 
 impl VPSNAL {
-    pub fn parse(bs: &mut BitVecReader) -> VPSNAL {
+    pub fn parse(bs: &mut BitVecReader) -> Result<VPSNAL> {
         let mut vps = VPSNAL {
             vps_id: bs.get_n(4),
             ..Default::default()
@@ -35,14 +37,14 @@ impl VPSNAL {
 
         vps.vps_max_layers = bs.get_n::<u8>(6) + 1;
         vps.vps_max_sub_layers = bs.get_n::<u8>(3) + 1;
-        vps.vps_temporal_id_nesting_flag = bs.get();
+        vps.vps_temporal_id_nesting_flag = bs.get()?;
 
         // vps_reserved_ffff_16bits
         assert!(bs.get_n::<u32>(16) == 0xFFFF);
 
-        vps.ptl.parse(bs, vps.vps_max_sub_layers);
+        vps.ptl.parse(bs, vps.vps_max_sub_layers)?;
 
-        vps.vps_sub_layer_ordering_info_present_flag = bs.get();
+        vps.vps_sub_layer_ordering_info_present_flag = bs.get()?;
 
         let i = if vps.vps_sub_layer_ordering_info_present_flag {
             0
@@ -51,10 +53,10 @@ impl VPSNAL {
         };
 
         for _ in i..vps.vps_max_sub_layers {
-            vps.vps_max_dec_pic_buffering.push(bs.get_ue() + 1);
-            vps.vps_num_reorder_pics.push(bs.get_ue());
+            vps.vps_max_dec_pic_buffering.push(bs.get_ue()? + 1);
+            vps.vps_num_reorder_pics.push(bs.get_ue()?);
 
-            let mut vps_max_latency_increase = bs.get_ue();
+            let mut vps_max_latency_increase = bs.get_ue()?;
             if vps_max_latency_increase > 0 {
                 vps_max_latency_increase -= 1;
             }
@@ -63,7 +65,7 @@ impl VPSNAL {
         }
 
         vps.vps_max_layer_id = bs.get_n(6);
-        vps.vps_num_layer_sets = bs.get_ue() + 1;
+        vps.vps_num_layer_sets = bs.get_ue()? + 1;
 
         for _ in 1..vps.vps_num_layer_sets {
             for _ in 0..=vps.vps_max_layer_id {
@@ -71,33 +73,33 @@ impl VPSNAL {
             }
         }
 
-        vps.vps_timing_info_present_flag = bs.get();
+        vps.vps_timing_info_present_flag = bs.get()?;
 
         if vps.vps_timing_info_present_flag {
             vps.vps_num_units_in_tick = bs.get_n(32);
             vps.vps_time_scale = bs.get_n(32);
-            vps.vps_poc_proportional_to_timing_flag = bs.get();
+            vps.vps_poc_proportional_to_timing_flag = bs.get()?;
 
             if vps.vps_poc_proportional_to_timing_flag {
-                vps.vps_num_ticks_poc_diff_one = bs.get_ue() + 1;
+                vps.vps_num_ticks_poc_diff_one = bs.get_ue()? + 1;
             }
 
-            vps.vps_num_hrd_parameters = bs.get_ue();
+            vps.vps_num_hrd_parameters = bs.get_ue()?;
 
             for i in 0..vps.vps_num_hrd_parameters {
                 let mut common_inf_present = false;
-                bs.get_ue(); // hrd_layer_set_idx
+                bs.get_ue()?; // hrd_layer_set_idx
 
                 if i > 0 {
-                    common_inf_present = bs.get();
+                    common_inf_present = bs.get()?;
                 }
 
-                HrdParameters::parse(bs, common_inf_present, vps.vps_max_sub_layers);
+                HrdParameters::parse(bs, common_inf_present, vps.vps_max_sub_layers)?;
             }
         }
 
         bs.skip_n(1); // vps_extension_flag
 
-        vps
+        Ok(vps)
     }
 }
